;**************************************************************************
;* FileName	: ADTEST.ASM
;* Date 	: 17.09.2001
;* File version : v1.00
;*
;* Author	: MIKO, Imre
;* Company	:
;* Homepage	: http://majki.fw.hu
;* E-mail	: majki@fw.hu
;*
;*-------------------------------------------------------------------------
;*
;* Description	: A/D converter module test
;*		  ==================================
;*		  
;*
;*
;*-------------------------------------------------------------------------
;*
;* Connections	:	       _______	 _______
;*			      |       \_/	|
;*		     -reset ==| -MCLR	    RB7 |== n.c.
;*		   potmeter ==| RA0	    RB6 |== n.c.
;*		       n.c. ==| RA1	    RB5 |== n.c.
;*		       n.c. ==| RA2	    RB4 |== n.c.
;*		       n.c. ==| RA3	    RB3 |== n.c.
;*		       n.c. ==| RA4	    RB2 |== n.c.
;*		       n.c. ==| RA5	    RB1 |== RxD (from MAX232)
;*		        GND ==| Vss	    RB0 |== TxD (to   MAX232)
;*		    quartz1 ==| OSC1	    Vdd |== +5V
;*		    quartz2 ==| OSC2	    Vss |== GND
;*		       n.c. ==| RC0	    RC7 |== n.c.
;*		       n.c. ==| RC1	    RC6 |== n.c.
;*		       n.c. ==| RC2	    RC5 |== n.c.
;*		       n.c. ==| RC3	    RC4 |== n.c.
;*			      |_________________|
;*				   PIC16F872 
;*
;*-------------------------------------------------------------------------
;*
;* Resource	: Ports 	  :    xx /   22 pin   (   %)
;*		  Data memory	  :    xx /  128 byte  (   %)
;*		  Prog memory	  :   xxx / 2048 word  (   %)
;*		  EEPROM	  :    xx /   64 byte  (   %)
;*		  Timers	  : 
;*		  Interrupt	  : 
;*		  CCP		  :
;*		  MSSP		  :
;*		  AD		  :
;*
;**************************************************************************
;* Revision History:
;*
;* 1.00	  17/09/2001 	Initial Release
;*
;**************************************************************************

	list	p=16f872, r=dec, l=0

;***** INCLUDES ***********************************************************

	include "p16f872.inc"
	include "..\..\modules\base.inc"

;***** CONFIG ************************************************************

CFG_1	EQU 	_XT_OSC & _WDT_OFF & _PWRTE_ON & _BODEN_ON & _LVP_OFF
CFG_2	EQU	_CPD_OFF & _WRT_ENABLE_OFF & _DEBUG_OFF & _CP_OFF

	__CONFIG CFG_1 & CFG_2
	__IDLOCS 0100h			; version

	EXPAND_MACROS	EXP_COND	; macro expansion mode

;***** DEFINES ************************************************************
;#define DEBUG				; for some debug message
;#define NO_DELAY			; for fast simulation
;#define NO_RS232			; for fast simulation

xtal_freq	EQU	4 MHz		; crystal frequency
core_freq	EQU	xtal_freq/4	; core operating frequency


; ----- porta -------------------------------------------------------------

#define		PORTA_0		PORTA,0		; analog in
#define		PORTA_1		PORTA,1		; analog in
#define		PORTA_2		PORTA,2		; analog in
#define		PORTA_3		PORTA,3		; analog in
#define		PORTA_4		PORTA,4		; free (open drain!)
#define		PORTA_5		PORTA,5		; analog in

; ----- portb -------------------------------------------------------------

#define		RS232_TxD	PORTB,0		; out
#define		RS232_RxD	PORTB,1		; in
#define		PORTB_2		PORTB,2		; free
#define		PORTB_3		PORTB,3		; free
#define		PORTB_4		PORTB,4		; free
#define		PORTB_5		PORTB,5		; free
#define		PORTB_6		PORTB,6		; free
#define		PORTB_7		PORTB,7		; free

; ----- portc -------------------------------------------------------------

#define		PORTC_0		PORTC,0		; free
#define		PORTC_1		PORTC,1		; free
#define		PORTC_2		PORTC,2		; free
#define		PORTC_3		PORTC,3		; free
#define		PORTC_4		PORTC,4		; free
#define		PORTC_5		PORTC,5		; free
#define		PORTC_6		PORTC,6		; free
#define		PORTC_7		PORTC,7		; free

;***** MACROS *************************************************************

	
	include "..\..\modules\wait.mac"
	include "..\..\modules\adc.mac"
	include "..\..\modules\rs232.mac"


;***** CONSTANT DEFINITIONS ***********************************************

option_val	EQU	00000010b	; Timer source : intclk / 8
trisa_val	EQU	00111111b	; TRISA value (all input)
trisb_val	EQU	11111111b	; TRISB value (all input)
trisc_val	EQU	11111111b	; TRISC value (all input)
adcon0_val	EQU	00000000b	; ADCON0 value (AD off)
adcon1_val	EQU	00000110b	; ADCON1 value (add digital input)
intcon_val	EQU	00100000b	; Interrupt control




;***** VARIABLE DEFINITIONS ***********************************************
	cblock	70h			; common RAM
		w_temp			; variable used for context saving
		status_temp		; variable used for context saving
		fsr_temp		; variable used for context saving
	endc

;--------------------------------------------------------------------------
	cblock	20h

		TEMP			; dummy register

	endc




;***** ENTRY POINT ********************************************************
		ORG	000h		; processor reset vector
		nop
		clrwdt
		clrf	STATUS
		goto	start


;***** IT HANDLER *********************************************************
;* Interrupt handler
;* <comment>
;**************************************************************************
		ORG	004h		; interrupt vector location
		movwf	w_temp		; save off current W register contents
		swapf	STATUS,w	; move STATUS register into W register
		movwf	status_temp	; save off contents of STATUS register

		movf	FSR,w		; save FSR
		movwf	fsr_temp
;--------------------------------------------------------------------------

		; <IT Code>

;--------------------------------------------------------------------------
		movf	fsr_temp,w	; restore FSR
		movwf	FSR

		swapf	status_temp,w	; retrieve copy of STATUS register
		movwf	STATUS		; restore pre-isr STATUS register contents
		swapf	w_temp,f
		swapf	w_temp,w	; restore pre-isr W register contents
		retfie			; return from interrupt




;***** REAL PROGRAM START *************************************************
start
;----- set configuration --------------------------------------------------
		clrf	PORTA		; clear latch
		clrf	PORTB		; clear latch
		clrf	PORTC		; clear latch
		bank1
		ERRORLEVEL -302
		movlw	option_val
		movwf	OPTION_REG	; set OPTION_REG
		movlw	trisa_val
		movwf	TRISA		; set TRISA
		movlw	trisb_val
		movwf	TRISB		; set TRISB
		movlw	trisc_val
		movwf	TRISC		; set TRISC
		movlw	adcon1_val	
		movwf	ADCON1		; set ADCON1
		bank0
		ERRORLEVEL +302
		movlw	adcon0_val	
		movwf	ADCON0		; set ADCON0
		movlw	intcon_val	
		movwf	INTCON		; set INTCON



;----- modules init -------------------------------------------------------



		RS232_INIT	9600, 8, 1
		AD_INIT		AD_Fosc8, AD_JUST_LEFT, 00000000b


;----- main cycle  --------------------------------------------------------


main_cycle	AD_GET AD_CH0

		movf	ADRESH,w
		RS232_SENDW

		WAIT	250 Millisec, 0

		goto	main_cycle






;***** SUB1 ***************************************************************
;* 
;* Input :              		; 
;* Output:  				; 
;* Clock :   
;**************************************************************************

sub1 


		return

;***** INCLUDES ***********************************************************

	include "..\..\modules\rs232.inc"
	include "..\..\modules\adc.inc"
	include "..\..\modules\wait.inc"


;**************************************************************************
	end				  ; end of program








